@@ -1,4 +1,4 @@
-(* $Id: modellib_SM.ml 5636 2014-04-02 11:30:19Z msekulla $
+(* $Id: modellib_SM.ml 5864 2014-06-02 13:12:47Z ohl $
 
    Copyright (C) 1999-2014 by
 
@@ -24,9 +24,9 @@
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  *)
 
 let rcs_file = RCS.parse "Modellib_SM" ["Lagragians"]
-    { RCS.revision = "$Revision: 5636 $";
-      RCS.date = "$Date: 2014-04-02 13:30:19 +0200 (Wed, 02 Apr 2014) $";
-      RCS.author = "$Author: msekulla $";
+    { RCS.revision = "$Revision: 5864 $";
+      RCS.date = "$Date: 2014-06-02 15:12:47 +0200 (Mon, 02 Jun 2014) $";
+      RCS.author = "$Author: ohl $";
       RCS.source
         = "$URL: svn+ssh://jr_reuter@login.hepforge.org/hepforge/svn/whizard/trunk/src/omega/src/modellib_SM.ml $" }
 
@@ -2257,9 +2257,9 @@ module SM_Rxi =
     type flavor = SM.flavor
     let flavors = SM.flavors
     let external_flavors = SM.external_flavors
-    type orders = SM.orders
+    (* Later: [type orders = SM.orders] *)
     type constant = SM.constant
-    let orders = SM.orders
+    (* Later: [let orders = SM.orders] *)
     let lorentz = SM.lorentz
     let color = SM.color
     let goldstone = SM.goldstone
@@ -2370,11 +2370,11 @@ module Groves (M : Model.Gauge) : Model.Gauge with module Ch = M.Ch =
     let flavor_symbol f = M.flavor_symbol (project f)
 
     type constant = M.constant
-    type orders = M.orders
+    (* Later: [type orders = M.orders] *)
     let constant_symbol = M.constant_symbol
     let max_degree = M.max_degree
     let parameters = M.parameters
-    let orders = M.orders
+    (* Later: [let orders = M.orders] *)
 
     let conjugate = function
       | M (_, g) as f -> inject g (M.conjugate (project f))
