@@ -1,4 +1,4 @@
-! WHIZARD 2.2.0 May 18 2014
+! WHIZARD 2.2.1 June 3 2014
 ! 
 ! Copyright (C) 1999-2014 by 
 !     Wolfgang Kilian <kilian@physik.uni-siegen.de>
@@ -1099,7 +1099,7 @@ end subroutine prc_template_me_test
     
     write (u, "(A)")  "* Configure library"
     write (u, "(A)")
-    call lib%configure ()
+    call lib%configure (os_data)
     
     write (u, "(A)")  "* Write makefile"
     write (u, "(A)")
@@ -1117,7 +1117,7 @@ end subroutine prc_template_me_test
     write (u, "(A)")
     call lib%load (os_data)
 
-    call lib%write (u)
+    call lib%write (u, libpath = .false.)
     
     write (u, "(A)")
     write (u, "(A)")  "* Probe library API:"
@@ -1262,7 +1262,7 @@ end subroutine prc_template_me_test
     
     write (u, "(A)")  "* Configure library"
     write (u, "(A)")
-    call lib%configure ()
+    call lib%configure (os_data)
     
     write (u, "(A)")  "* Write makefile"
     write (u, "(A)")
@@ -1280,7 +1280,7 @@ end subroutine prc_template_me_test
     write (u, "(A)")
     call lib%load (os_data)
 
-    call lib%write (u)
+    call lib%write (u, libpath = .false.)
     
     write (u, "(A)")
     write (u, "(A)")  "* Probe library API:"
